@@ -8,7 +8,6 @@
 
 import torch
 import torchplus as tp
-from ..tensor import return_tensor_wrapper
 import torch.nn as nn
 import torch.nn.functional as F
 from pyctlib import vector
@@ -16,8 +15,8 @@ import inspect
 
 F_key = vector(dir(F)).filter(lambda x: not x.startswith("_")).filter(lambda x: not inspect.isclass(eval("F.{}".format(x)))).filter(lambda x: x[0].islower())
 
-template = "@return_tensor_wrapper\ndef {key}(*args, **kwargs): return F.{key}(*args, **kwargs)"
-# template = "def {key}(*args, **kwargs): return F.{key}(*args, **kwargs)"
+# template = "@return_tensor_wrapper\ndef {key}(*args, **kwargs): return F.{key}(*args, **kwargs)"
+template = "{key} = F.{key}"
 
 # F_key.apply(lambda x: exec(template.format(key=x)))
 
